@@ -16,17 +16,16 @@ package org.codehaus.plexus.classworlds;
  * limitations under the License.
  */
 
-import junit.framework.TestCase;
+import org.junit.jupiter.api.Test;
 
-public class UrlUtilsTest
-    extends TestCase
-{
+import static org.junit.jupiter.api.Assertions.assertEquals;
 
-    public void testNormalizeUrlPath()
-    {
-        assertEquals( "org/codehaus/Test.class", UrlUtils.normalizeUrlPath( "org/codehaus/Test.class" ) );
-        assertEquals( "org/Test.class", UrlUtils.normalizeUrlPath( "org/codehaus/../Test.class" ) );
-        assertEquals( "../../some.jar/org/Test.class", UrlUtils.normalizeUrlPath( "../../some.jar/org/Test.class" ) );
+class UrlUtilsTest {
+
+    @Test
+    public void testNormalizeUrlPath() {
+        assertEquals("org/codehaus/Test.class", UrlUtils.normalizeUrlPath("org/codehaus/Test.class"));
+        assertEquals("org/Test.class", UrlUtils.normalizeUrlPath("org/codehaus/../Test.class"));
+        assertEquals("../../some.jar/org/Test.class", UrlUtils.normalizeUrlPath("../../some.jar/org/Test.class"));
     }
-
 }
